<template>
  <a-card
    title=""
    :bordered="false"
  >
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='单据号'>
              <j-input
                placeholder='单据号检索'
                v-model='queryParam.num'
              ></j-input>
            </a-form-item>
          </a-col>
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='保障保修单'>
              <j-input
                placeholder='故障报修单检索'
                v-model='queryParam.reportNum'
              ></j-input>
            </a-form-item>
          </a-col>
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='统一编号'>
              <j-input
                placeholder='统一编号检索'
                v-model='queryParam.equipmentNum'
              ></j-input>
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button
        type='primary'
        @click='searchQuery'
        icon='search'
      >查询</a-button>
      <a-button
        type='primary'
        @click='searchReset'
        icon='reload'
        style='margin-left: 8px'
      >重置</a-button>
      <!-- <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button> -->
      <!-- <a-button type="primary" icon="download" @click="handleExportXls('产品质量隐患确认')">导出</a-button>
      <a-upload name="file" :showUploadList="false" :multiple="false" :headers="tokenHeader" :action="importExcelUrl" @change="handleImportExcel">
        <a-button type="primary" icon="import">导入</a-button>
      </a-upload> -->
      <!-- 高级查询区域 -->
      <!-- <j-super-query :fieldList="superFieldList" ref="superQueryModal" @handleSuperQuery="handleSuperQuery"></j-super-query>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel"><a-icon type="delete"/>删除</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown> -->
    </div>

    <!-- table区域-begin -->
    <div>
      <div
        class="ant-alert ant-alert-info"
        style="margin-bottom: 16px;"
      >
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a
          style="margin-left: 24px"
          @click="onClearSelected"
        >清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        :scroll="{x:true}"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        class="j-table-force-nowrap"
        @change="handleTableChange"
      >

        <template
          slot="htmlSlot"
          slot-scope="text"
        >
          <div v-html="text"></div>
        </template>
        <template
          slot="imgSlot"
          slot-scope="text,record"
        >
          <span
            v-if="!text"
            style="font-size: 12px;font-style: italic;"
          >无图片</span>
          <img
            v-else
            :src="getImgView(text)"
            :preview="record.id"
            height="25px"
            alt=""
            style="max-width:80px;font-size: 12px;font-style: italic;"
          />
        </template>
        <template
          slot="fileSlot"
          slot-scope="text"
        >
          <span
            v-if="!text"
            style="font-size: 12px;font-style: italic;"
          >无文件</span>
          <a-button
            v-else
            :ghost="true"
            type="primary"
            icon="download"
            size="small"
            @click="downloadFile(text)"
          >
            下载
          </a-button>
        </template>

        <span
          slot="action"
          slot-scope="text, record"
        >
          <a
            @click="handleEdit(record)"
            :disabled="record.isConfirm==='yes'"
            v-has="'quanlity:confirm'"
          >确认</a>

          <!-- <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a @click="handleDetail(record)">详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown> -->
        </span>

      </a-table>
    </div>

    <quanlity-confirm-modal
      ref="modalForm"
      @ok="modalFormOk"
    ></quanlity-confirm-modal>
  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import QuanlityConfirmModal from './modules/QuanlityConfirmModal'

export default {
  name: 'QuanlityConfirmList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    QuanlityConfirmModal
  },
  data() {
    return {
      description: '产品质量隐患确认管理页面',
      disableMixinCreated: true,
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        {
          title: '单据号',
          align: "center",
          dataIndex: 'num',
          width: 200
        },
        {
          title: '故障报修单',
          align: "center",
          dataIndex: 'reportNum',
          width: 200
        },
        {
          title: '设备名称',
          align: "center",
          dataIndex: 'equipmentName',
          width: 200
        },
        {
          title: '设备型号',
          align: "center",
          dataIndex: 'equipmentModel',
          width: 200
        },
        {
          title: '统一编号',
          align: "center",
          dataIndex: 'equipmentNum',
          width: 200
        },
        {
          title: '加工零件号',
          align: "center",
          dataIndex: 'partNumber',
          width: 200
        },
        {
          title: '批次号',
          align: "center",
          dataIndex: 'batchNo',
          width: 200
        },
        {
          title: '件数',
          align: "center",
          dataIndex: 'quantity',
          width: 100
        },
        {
          title: '操作员',
          align: "center",
          dataIndex: 'operator_dictText',
          width: 100
        },
        {
          title: '是否已确认',
          align: "center",
          dataIndex: 'isConfirm_dictText'
          ,
          width: 100
        },
        {
          title: '确认领导',
          align: "center",
          dataIndex: 'leader_dictText'
          ,
          width: 100
        },
        {
          title: '领导确认时间',
          align: "center",
          dataIndex: 'confirmTime',
          customRender: function (text) {
            return !text ? "" : (text.length > 10 ? text.substr(0, 10) : text)
          },
          width: 200
        },
        {
          title: '产品损失情况',
          align: "center",
          dataIndex: 'condition',
          width: 100
        },
        {
          title: '损失情况分析',
          align: "center",
          dataIndex: 'conditionAnalysis',
          width: 200
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: "center",
          fixed: "right",
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: "/li/quanlityConfirm/list",
        delete: "/li/quanlityConfirm/delete",
        deleteBatch: "/li/quanlityConfirm/deleteBatch",
        exportXlsUrl: "/li/quanlityConfirm/exportXls",
        importExcelUrl: "li/quanlityConfirm/importExcel",

      },
      dictOptions: {},
      superFieldList: [],
    }
  },
  created() {
    if (this.$route.query) {
      this.queryParam.id = this.$route.query.id;
    }
    this.loadData()
    this.initDictConfig();
  },
  computed: {
    importExcelUrl: function () {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
    },
  },
  methods: {
    initDictConfig() {
    },
    getSuperFieldList() {
      let fieldList = [];
      fieldList.push({ type: 'string', value: 'reportId', text: '故障报修单ID' })
      fieldList.push({ type: 'string', value: 'condition', text: '产品损失情况' })
      fieldList.push({ type: 'string', value: 'conditionAnalysis', text: '损失情况分析' })
      fieldList.push({ type: 'string', value: 'partNumber', text: '零件号' })
      fieldList.push({ type: 'string', value: 'batchNo', text: '批次号' })
      fieldList.push({ type: 'int', value: 'qunatity', text: '件数' })
      fieldList.push({ type: 'string', value: 'leader', text: '确认领导' })
      fieldList.push({ type: 'date', value: 'confirmTime', text: '领导确认时间' })
      fieldList.push({ type: 'string', value: 'isConfirm', text: '是否已确认' })
      this.superFieldList = fieldList
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>